@@ -35,24 +35,26 @@ class KCharSelectDia : public KXmlGuiWindow
 public:
   KCharSelectDia();
 
+  friend class KCharSelectBookmarkOwner;
+
 protected:
-  void closeEvent(QCloseEvent *event);
+  void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
 
   QGridLayout *grid;
   KCharSelect *charSelect;
   QLineEdit   *lined;
   QPushButton *bClip;
 
-  QChar vChr;
+  uint vChr;
   QFont vFont;
   bool _rtl;
 
-protected slots:
-  void charChanged(const QChar &_chr);
+protected Q_SLOTS:
+  void charChanged(uint _chr);
   void fontSelected(const QFont &_font);
   void add()
   { add(vChr); }
-  void add(const QChar &_chr);
+  void add(uint _chr);
   void toClip();
   void toClipUTF8();
   void toClipHTML();
